package com.vendor.burn.serial.workers;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.define.IChecker;
import com.vendor.burn.model.receive.ReceiveTimeOutException;
import com.vendor.burn.serial.workers.AddressBurnerWorker;
import com.vendor.burn.serial.workers.CallLibJTAGWorker;
import com.vendor.platform.api.statistics.ToolStatistics;
import java.io.IOException;
import org.eclipse.core.runtime.IProgressMonitor;

public class BadCheckBurnerWorker extends AddressBurnerWorker {
  private static StringBuilder content = new StringBuilder();
  
  public BadCheckBurnerWorker(IChecker checker) {
    super((IBurner)checker);
  }
  
  public boolean initBoard() throws IOException, ReceiveTimeOutException {
    debugPrintln("InitBoard Start");
    if (!bootDownload(null))
      return false; 
    return true;
  }
  
  public boolean eraseBad(IProgressMonitor uimonitor) throws ReceiveTimeOutException, IOException {
    ToolStatistics.INSTANCE.logUsage("BurnTool", "Nand Scrub", "ChipName: " + this.burner
        .getBurnContext().getDeviceSetting().getName());
    ToolStatistics.INSTANCE.logToolInUse("BurnTool");
    String versionInfo = getVersionInfo("Nand Scrub");
    CallLibJTAGWorker.printDebugInfo(versionInfo);
    monitor.getEvent().setSuccess(false);
    setProgressMonitor(uimonitor);
    uimonitor.beginTask("Erase Bad Blocks", 100);
    deleteContent(content);
    uimonitor.setTaskName("Init Board");
    boolean initBoard = initBoard();
    if (!initBoard)
      return false; 
    uimonitor.internalWorked(0.2D);
    String received = getCurReceived();
    content.append(received);
    if (received.toUpperCase().indexOf("NAND") == -1) {
      warningln("No Nand Found.");
      return false;
    } 
    uimonitor.setTaskName("Sending nand scrub command.");
    uimonitor.internalWorked(0.6D);
    boolean sendCommand = sendCommand("nand scrub", 10000);
    if (!sendCommand) {
      warningln("Failed to execute nand scrub command.");
      return false;
    } 
    content.append(getCurReceived());
    monitor.getEvent().setSuccess(true);
    monitor.getEvent().setMessage(content.toString());
    infoln("Nand scrub successful.");
    return true;
  }
  
  public boolean check(IProgressMonitor uimonitor) throws ReceiveTimeOutException, IOException {
    ToolStatistics.INSTANCE.logUsage("BurnTool", "Bad Check", "ChipName: " + this.burner
        .getBurnContext().getDeviceSetting().getName());
    ToolStatistics.INSTANCE.logToolInUse("BurnTool");
    String versionInfo = getVersionInfo("Bad Check");
    CallLibJTAGWorker.printDebugInfo(versionInfo);
    try {
      monitor.getEvent().setSuccess(false);
      setProgressMonitor(uimonitor);
      uimonitor.beginTask("Check Bad Blocks", 100);
      deleteContent(content);
      uimonitor.setTaskName("Init Board");
      boolean initBoard = initBoard();
      if (!initBoard)
        return false; 
      uimonitor.internalWorked(0.2D);
      String received = getCurReceived();
      content.append(received);
      if (received.toUpperCase().indexOf("NAND") == -1) {
        warningln("No Nand Found.");
        return false;
      } 
      uimonitor.setTaskName("Sending Check command.");
      uimonitor.internalWorked(0.6D);
      boolean sendCommand = sendCommand("nand bad", 10000);
      if (!sendCommand) {
        warningln("Failed to get bad block info.");
        return false;
      } 
      onAdataAvailable(serialReceived);
      content.append(serialReceived);
      monitor.getEvent().setSuccess(true);
      monitor.getEvent().setMessage(content.toString());
    } finally {
      uimonitor.done();
    } 
    return true;
  }
}
